@@ -50,7 +50,7 @@ range_validate <- function(object, range, ukn_ok = TRUE) {
   }
   if (length(range) != 2) {
     rlang::abort(
-      paste0("`range` must have an upper and lower bound. ", ukn_txt)
+      paste("`range` must have two values: an upper and lower bound.", ukn_txt)
     )
   }
 
@@ -101,7 +101,6 @@ range_set <- function(object, range) {
         type = object$type,
         range = range,
         inclusive = object$inclusive,
-        default = object$default,
         trans = object$trans,
         values = object$values,
         label = object$label
